@@ -272,7 +272,7 @@ struct MemoryDump
  */
 class DebuggerDriver : public TDEProcess
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     DebuggerDriver();
     virtual ~DebuggerDriver() = 0;
