@@ -19,8 +19,8 @@
 #include <kkeydialog.h>
 #include <kanimwidget.h>
 #include <twin.h>
-#include <ntqlistbox.h>
-#include <ntqfileinfo.h>
+#include <tqlistbox.h>
+#include <tqfileinfo.h>
 #include "dbgmainwnd.h"
 #include "debugger.h"
 #include "commandids.h"
