@@ -94,7 +94,7 @@ struct ExprValue
 
 class ValueEdit : public TQLineEdit
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     ValueEdit(ExprWnd* parent);
     ~ValueEdit();
@@ -115,7 +115,7 @@ signals:
 
 class ExprWnd : public TQListView
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     ExprWnd(TQWidget* parent, const TQString& colHeader, const char* name);
     ~ExprWnd();
